Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyValue ¶
type KeyValue struct {
Key string `json:"key,omitempty"`
Hash string `json:"hash"`
Data []byte `json:"data"`
Version int `json:"version"`
}
KeyValue holds a singke key value pair, along with the version (the creation timestamp)
type KeyValueVersions ¶
KeyValueVersions holds the full history for a key value pair
type KeysResponse ¶
type KeysResponse struct {
Keys []*KeyValue `json:"keys"`
}
KeysResponse is a wrapper for a list of key value pairs
Click to show internal directories.
Click to hide internal directories.